==> billogram-foundation-4.7.1.tgz: package/modules/components/textbox/TextboxSymbolText.js <==
import React, { PropTypes } from 'react';
import ReactDOM from 'react-dom';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';
import purebem from 'purebem';

import isNullOrEmpty from '../../utils/isNullOrEmpty';
import noop from '../../utils/noop';


export default ({
    block,
    displayName,
    Spinner
}= {}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');
    invariant(Spinner !== undefined, 'Missing Spinner component.');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            loading: PropTypes.bool,
            mobileIconFallback: PropTypes.string,
            onClick: PropTypes.func,
            text: PropTypes.string
        },

        getDefaultProps() {
            return {
                children: null,
                disabled: false,
                loading: false,
                mobileIconFallback: null,
                onClick: noop,
                text: ''
            };
        },

        onClick(evt) {
            if (this.props.disabled) {
                return;
            }

            this.props.onClick(evt);
        },

        symbolRefCallback(component) {
            if (component === null) {
                return null;
            }

            const input = ReactDOM.findDOMNode(this.input);
            const padding = parseFloat(window.getComputedStyle(component)['padding-right'], 10);

            input.style.paddingRight = component.getBoundingClientRect().width + (Number.isNaN(padding) ? 0 : padding) + 'px';
        },

        renderMobileIconFallback() {
            const { mobileIconFallback } = this.props;
            if (mobileIconFallback === null) {
                return null;
            }

            return (
                <i
                    className={ purebem.many(block('symbol-icon'), `bi-${mobileIconFallback}`) }
                    onClick={ this.onClick } />
            );
        },

        renderSymbol() {
            const { loading, mobileIconFallback, text } = this.props;
            if (loading) {
                return (
                    <span
                        className={ block('symbol-spinner') }
                        ref={ this.symbolRefCallback }>
                        <Spinner
                            autoSize={ true } />
                    </span>
                );
            }

            const hasMobileIconFallback = mobileIconFallback !== null;
            return (
                <div>
                    { this.renderMobileIconFallback() }
                    <span
                        className={ block('symbol', { hasMobileIconFallback }) }
                        onClick={ this.onClick }
                        ref={ this.symbolRefCallback }>
                        { text }
                    </span>
                </div>
            );
        },

        render() {
            const { children, disabled, onClick } = this.props;
            const clickable = !isNullOrEmpty(onClick) && onClick !== noop;

            const node = React.Children.only(children);
            const textbox = React.cloneElement(node, {
                ref: (c) => {
                    this.input = c;
                    if (typeof node.ref === 'function') {
                        node.ref(c);
                    }
                }
            });

            return (
                <div className={ block({ clickable, disabled }) }>
                    { textbox }
                    { this.renderSymbol() }
                </div>
            );
        }

    });

};

==> billogram-foundation-4.8.4.tgz: package/modules/components/textbox/TextboxSymbolText.js <==
import React, { PropTypes } from 'react';
import ReactDOM from 'react-dom';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';
import purebem from 'purebem';

import isNullOrEmpty from '../../utils/isNullOrEmpty';
import noop from '../../utils/noop';


export default ({
    block,
    displayName,
    Spinner,
}= {}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');
    invariant(Spinner !== undefined, 'Missing Spinner component.');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            loading: PropTypes.bool,
            mobileIconFallback: PropTypes.string,
            onClick: PropTypes.func,
            text: PropTypes.string,
        },

        getDefaultProps() {
            return {
                children: null,
                disabled: false,
                loading: false,
                mobileIconFallback: null,
                onClick: noop,
                text: '',
            };
        },

        onClick(evt) {
            if (this.props.disabled) {
                return;
            }

            this.props.onClick(evt);
        },

        symbolRefCallback(component) {
            if (component === null) {
                return null;
            }

            const input = ReactDOM.findDOMNode(this.input);
            const padding = parseFloat(window.getComputedStyle(component)['padding-right'], 10);

            input.style.paddingRight = `${component.getBoundingClientRect().width + (Number.isNaN(padding) ? 0 : padding)}px`;
        },

        renderMobileIconFallback() {
            const { mobileIconFallback } = this.props;
            if (mobileIconFallback === null) {
                return null;
            }

            return (
                <i
                    className={ purebem.many(block('symbol-icon'), `bi-${mobileIconFallback}`) }
                    onClick={ this.onClick } />
            );
        },

        renderSymbol() {
            const { loading, mobileIconFallback, text } = this.props;
            if (loading) {
                return (
                    <span
                        className={ block('symbol-spinner') }
                        ref={ this.symbolRefCallback }>
                        <Spinner
                            autoSize={ true } />
                    </span>
                );
            }

            const hasMobileIconFallback = mobileIconFallback !== null;
            return (
                <div>
                    { this.renderMobileIconFallback() }
                    <span
                        className={ block('symbol', { hasMobileIconFallback }) }
                        onClick={ this.onClick }
                        ref={ this.symbolRefCallback }>
                        { text }
                    </span>
                </div>
            );
        },

        render() {
            const { children, disabled, onClick } = this.props;
            const clickable = !isNullOrEmpty(onClick) && onClick !== noop;

            const node = React.Children.only(children);
            const textbox = React.cloneElement(node, {
                ref: (c) => {
                    this.input = c;
                    if (typeof node.ref === 'function') {
                        node.ref(c);
                    }
                },
            });

            return (
                <div className={ block({ clickable, disabled }) }>
                    { textbox }
                    { this.renderSymbol() }
                </div>
            );
        },

    });

};
